#include "bgraphic.hpp"

Graphics::Graphics()
{
	// detect the graphics card installed
	int gdriver = VGA;
	int gmode = VGAMED;

	initgraph(&gdriver, &gmode, "");
	if (graphresult() != grOk) {
	  Terminate();
	  cerr << "\nUnable to open graphics device";
	  exit(1);
	}

	// compute the screen dimensions
	struct viewporttype screen;
	getviewsettings(&screen);
	screen_width = abs(screen. right - screen. left);
	screen_height = abs(screen. top - screen. bottom);

	// compute the size of a character
	font_width = textwidth("A");
	font_height = textheight("A");
}

void Graphics::DrawDot(int color, int x, int y)
{
	putpixel(x, screen_height - y, color);
}


void Graphics::DrawBox(int color, int style, BOX_TYPE* box)
{
	int polygon [10];
	polygon [0] = box->x1;
	polygon [1] = screen_height - box->y1;
	polygon [2] = box->x1;
	polygon [3] = screen_height - box->y2;
	polygon [4] = box->x2;
	polygon [5] = screen_height - box->y2;
	polygon [6] = box->x2;
	polygon [7] = screen_height - box->y1;
	polygon [8] = box->x1;
	polygon [9] = screen_height - box->y1;

	setlinestyle(style, 1, 1);
	setcolor(color);
	drawpoly(5, polygon);
}


void Graphics::DrawCircle(int color,
			  int style,
			  int x, int y, int radius)
{
	setcolor(color);
	setlinestyle(style, 1, 1);
	ellipse(x, screen_height - y, 0, 360, radius, radius);
}


void Graphics::DrawLine(int color, int style, BOX_TYPE* box)
{
	setcolor(color);
	setlinestyle(style, 1, 1);
	moveto(box->x1, screen_height - box->y1);
	lineto(box->x2, screen_height - box->y2);
}



void Graphics::FillBox(int color, BOX_TYPE* box)
{
	setcolor(color);
	setlinestyle(SOLID_LINE, 1, 1);
	setfillstyle(SOLID_FILL, color);

	int polygon [8];
	polygon [0] = box->x1;
	polygon [1] = screen_height - box->y1;
	polygon [2] = box->x1;
	polygon [3] = screen_height - box->y2;
	polygon [4] = box->x2;
	polygon [5] = screen_height - box->y2;
	polygon [6] = box->x2;
	polygon [7] = screen_height - box->y1;

	fillpoly(4, polygon);
}


void Graphics::FillCircle(int color, int x, int y, int radius)
{
	setcolor(color);
	setlinestyle(SOLID_LINE, 1, 1);
	fillellipse(x, screen_height - y, radius, radius);
}


void Graphics::PutString(int color, int x, int y, char* string)
{
	setcolor(color);
	settextjustify(LEFT_TEXT, BOTTOM_TEXT);
	outtextxy(x, screen_height - y, string);
}


void Graphics::Terminate()
{
	// exit graphics mode
	closegraph();
}

Graphics::~Graphics()
{
	// close the graphics mode
	Terminate();
}

